==> haskell-selective-0.4.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 selective
version:              0.4.2
visibility:           public
id:                   selective-0.4.2-8FjPQCYN2MK6bLv5uaQhv
key:                  selective-0.4.2-8FjPQCYN2MK6bLv5uaQhv
license:              MIT
copyright:            Andrey Mokhov, 2018-2021
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.

category:             Control
abi:                  3808077aee713ef094e6a19694fef010
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer

import-dirs:          /usr/lib/ghc-8.10.4/site-local/selective-0.4.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/selective-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/selective-0.4.2
hs-libraries:         HSselective-0.4.2-8FjPQCYN2MK6bLv5uaQhv
depends:              base-4.14.1.0 containers-0.6.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-selective-0.4.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 selective
version:              0.4.2
visibility:           public
id:                   selective-0.4.2-9woGI5yC1CH2Utu7bJFbdl
key:                  selective-0.4.2-9woGI5yC1CH2Utu7bJFbdl
license:              MIT
copyright:            Andrey Mokhov, 2018-2021
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.

category:             Control
abi:                  48d721e115e9f6b144cd1dd7122f357b
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer

import-dirs:          /usr/lib/ghc-8.10.4/site-local/selective-0.4.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/selective-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/selective-0.4.2
hs-libraries:         HSselective-0.4.2-9woGI5yC1CH2Utu7bJFbdl
depends:              base-4.14.1.0 containers-0.6.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
